| Title: | Extract Data from Google Takeout |
|---|---|
| Description: | Provides functions to analyze data exported from 'Google Takeout'. The package supports unzipping archives and extracting user review data from Google Business Profile exports into tidy data frames for further analysis. |
| Authors: | Jordi Rosell [aut, cre, cph] (ORCID: <https://orcid.org/0000-0002-4349-1458>) |
| Maintainer: | Jordi Rosell <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0.9000 |
| Built: | 2026-05-19 08:43:44 UTC |
| Source: | https://github.com/jrosell/gtakeout |
Extract the reviews form a Takedown zip file. #'
gtakeout_reviews(zipfile, ..., exdir = here::here("data"))gtakeout_reviews(zipfile, ..., exdir = here::here("data"))
zipfile |
Required path to the zip file containing the reviews |
... |
Other optional arguments |
exdir |
Optional directory to extract the contents of the zip file |
A data frame of reviews
zip_path <- system.file( "extdata", "takeout-example.zip", package = "gtakeout" ) gtakeout_reviews(zip_path, exdir = tempdir())zip_path <- system.file( "extdata", "takeout-example.zip", package = "gtakeout" ) gtakeout_reviews(zip_path, exdir = tempdir())